# $Id$

package MT::Plugin::MultiImageUploader;

use strict;
use MT::Plugin;
use base qw( MT::Plugin );

use vars qw($PLUGIN_NAME $VERSION);
$PLUGIN_NAME = 'MultiImageUploader';
$VERSION = '0.50';

use MT;
my $plugin = MT::Plugin::MultiImageUploader->new({
    id => 'multiimageuploader',
    key => __PACKAGE__,
    name => $PLUGIN_NAME,
    version => $VERSION,
    description => "<MT_TRANS phrase='Plug-in that up-loads two or more images, and the thumbnail makes, and create a WEB page.'>",
    author_name => 'M-Logic, Inc.',
    author_link => 'http://m-logic.co.jp/',
    l10n_class => 'MultiImageUploader::L10N',
    blog_config_template => \&blog_config_template,
    settings => new MT::PluginSettings([
        ['multi_image_uploader_dir', { Default => 'upload_files' }],
    ]),
    registry => {
        applications => {
            cms => {
                methods => {
                  multi_image_uploader_upload => '$MultiImageUploader::MultiImageUploader::CMS::upload',
                  multi_image_uploader_save => '$MultiImageUploader::MultiImageUploader::CMS::save',
                },
                menus => {
                    'create:multiimageupload' => {
                        label       => "MultiImageUploader",
                        order       => 10100,
                        mode        => "multi_image_uploader_upload",
                        view        => "blog",
                        permission  => 'upload',
                    },
                },
            },
        },
    },
});

MT->add_plugin($plugin);

sub instance { $plugin; }

sub doLog {
    my ($msg) = @_; 
    return unless defined($msg);

    require MT::Log;
    my $log = MT::Log->new;
    $log->message($msg) ;
    $log->save or die $log->errstr;
}

sub blog_config_template {
    my $tmpl = <<'EOT';
    <mtapp:setting
        id="multi_image_uploader_dir"
        label="<__trans phrase="Upload directory:">">
        <input type="text" name="multi_image_uploader_dir" id="multi_image_uploader_dir" value="<mt:var name="multi_image_uploader_dir" escape="html">" />
    </mtapp:setting>
EOT
}

sub multi_image_uploader_dir {
    my $plugin = shift;
    my ($blog_id) = @_;
    my %plugin_param;

    $plugin->load_config(\%plugin_param, 'blog:'.$blog_id);
    my $value = $plugin_param{multi_image_uploader_dir};
    $value;
}

1;